==> haskell-text-zipper-0.13-127.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-text-zipper.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-zipper
version:              0.13
visibility:           public
id:                   text-zipper-0.13-I9xIkAkNCdFHOF70IpFfXX
key:                  text-zipper-0.13-I9xIkAkNCdFHOF70IpFfXX
license:              BSD-3-Clause
copyright:            (c) 2015 Jonathan Daugherty
maintainer:           cygnus@foobox.com
author:               Jonathan Daugherty <cygnus@foobox.com>
homepage:             https://github.com/jtdaugherty/text-zipper/
synopsis:             A text editor zipper library
description:          This library provides a zipper and API for editing text.
category:             Text
abi:                  bc8d607487c033ee9b338eef21ea5e9c
exposed:              True
exposed-modules:
    Data.Text.Zipper Data.Text.Zipper.Generic
    Data.Text.Zipper.Generic.Words

hidden-modules:       Data.Text.Zipper.Vector
import-dirs:          /usr/lib/ghc-9.6.6/site-local/text-zipper-0.13
library-dirs:         /usr/lib/ghc-9.6.6/site-local/text-zipper-0.13
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/text-zipper-0.13
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-zipper
hs-libraries:         HStext-zipper-0.13-I9xIkAkNCdFHOF70IpFfXX
depends:
    base-4.18.2.1 deepseq-1.4.8.1 text-2.0.2
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:   /usr/share/doc/haskell-text-zipper/html/text-zipper.haddock
haddock-html:         /usr/share/doc/haskell-text-zipper/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-zipper-0.13-128-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-text-zipper.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-zipper
version:              0.13
visibility:           public
id:                   text-zipper-0.13-6en0cnvMMd57tWWE0scrPW
key:                  text-zipper-0.13-6en0cnvMMd57tWWE0scrPW
license:              BSD-3-Clause
copyright:            (c) 2015 Jonathan Daugherty
maintainer:           cygnus@foobox.com
author:               Jonathan Daugherty <cygnus@foobox.com>
homepage:             https://github.com/jtdaugherty/text-zipper/
synopsis:             A text editor zipper library
description:          This library provides a zipper and API for editing text.
category:             Text
abi:                  b016a23c915e51e18f66463758abebe6
exposed:              True
exposed-modules:
    Data.Text.Zipper Data.Text.Zipper.Generic
    Data.Text.Zipper.Generic.Words

hidden-modules:       Data.Text.Zipper.Vector
import-dirs:          /usr/lib/ghc-9.6.6/site-local/text-zipper-0.13
library-dirs:         /usr/lib/ghc-9.6.6/site-local/text-zipper-0.13
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/text-zipper-0.13
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-zipper
hs-libraries:         HStext-zipper-0.13-6en0cnvMMd57tWWE0scrPW
depends:
    base-4.18.2.1 deepseq-1.4.8.1 text-2.0.2
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:   /usr/share/doc/haskell-text-zipper/html/text-zipper.haddock
haddock-html:         /usr/share/doc/haskell-text-zipper/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
